@@ -32,7 +32,6 @@
 #include <ctype.h>
 #include <stdarg.h>
 #include <stdlib.h>
-#include <malloc.h>
 #include <string.h>
 #include <sys/socket.h>
 
@@ -433,6 +432,14 @@ char *bt_compidtostr(int compid)
 		return "Accel Semiconductor Ltd.";
 	case 75:
 		return "Continental Automotive Systems";
+	case 76:
+		return "Apple, Inc.";
+	case 77:
+		return "Staccato Communications, Inc.";
+	case 78:
+		return "Avago Technologies";
+	case 79:
+		return "APT Ltd.";
 	case 65535:
 		return "internal use";
 	default:
